erfcinvf
产品支持情况
- Ascend 950PR/Ascend 950DT:支持
- Atlas A3 训练系列产品/Atlas A3 推理系列产品:不支持
- Atlas A2 训练系列产品/Atlas A2 推理系列产品:不支持
- Atlas 200I/500 A2 推理产品:不支持
- Atlas 推理系列产品AI Core:不支持
- Atlas 推理系列产品Vector Core:不支持
- Atlas 训练系列产品:不支持
功能说明
获取输入数据的逆互补误差函数值。
函数原型
C++
inline float erfcinvf(float x)
参数说明
表1 函数形参说明
| 参数名 | 输入/输出 | 描述 |
|---|---|---|
| x | 输入 | 源操作数。 |
返回值说明
- 当x为0时,返回值为inf。
- 当x为nan时,返回值为nan。
- 当x为2时,返回值为-inf。
- 当x∉[0,2]时,返回nan。
约束说明
无
需要包含的头文件
使用该接口需要包含"simt_api/math_functions.h"头文件。
C++
#include "simt_api/math_functions.h"
调用示例
SIMT编程场景:
C++__global__ __launch_bounds__(256) void compute_erfcinvf(float *result, const float *x, uint32_t count) { const uint32_t idx = blockIdx.x * blockDim.x + threadIdx.x; if (idx >= count) { return; } result[idx] = erfcinvf(x[idx]); }SIMD与SIMT混合编程场景:
C++__simt_vf__ __launch_bounds__(256) inline void compute_erfcinvf_vf(__gm__ float *result, __gm__ const float *x, uint32_t count) { const uint32_t idx = blockIdx.x * blockDim.x + threadIdx.x; if (idx >= count) { return; } result[idx] = erfcinvf(x[idx]); } __global__ __vector__ void run_erfcinvf(__gm__ float *result, __gm__ const float *x, uint32_t count) { asc_vf_call<compute_erfcinvf_vf>(dim3(256), result, x, count); }
输入输出示例如下:
Text
x:0.25, 0.5, 0.75, 1
result: 0.8134198 0.4769363 0.2253121 0